(analyse expression)Analyse an expression. On success Returns a map of the form: {:result true, :variables <variables>}
where <variables> is a collection of maps of the form {:name "variable name" :pos 6}
On error returns a map of the form: {:errors <collection of error message strings>}
Analyse an expression.
On success Returns a map of the form:
{:result true, :variables <variables>}
where <variables> is a collection of maps of the form
{:name "variable name"
:pos 6}
On error returns a map of the form:
{:errors <collection of error message strings>}(evaluate expression pipeline-values)Evaluate an expression.
Evaluate returns the eventual value of the expression, which may be any scalar type supported by the language.
On success returns a map of the form: {:result <result of evaluating expression>}
On error returns a map of the form: {:errors <collection of error message strings>}
Evaluate an expression.
Evaluate returns the eventual value of the expression, which may be any
scalar type supported by the language.
On success returns a map of the form:
{:result <result of evaluating expression>}
On error returns a map of the form:
{:errors <collection of error message strings>}(interpret expression pipeline-values)Interpret an expression.
Interpret returns the truthiness of the eventual value of the expression.
On success returns a map of the form: {:result <boolean result of interpreting expression>}
On error returns a map of the form: {:errors <collection of error message strings>}
Interpret an expression.
Interpret returns the truthiness of the eventual value of the expression.
On success returns a map of the form:
{:result <boolean result of interpreting expression>}
On error returns a map of the form:
{:errors <collection of error message strings>}(parse expression)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |